@@ -13,10 +13,14 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_qldb.literals import (
+    ErrorCause,
+    ExportStatus,
+    LedgerState,
+    S3ObjectEncryptionType,
+    StreamStatus,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -55,7 +59,7 @@ _RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
         "LedgerName": str,
         "RoleArn": str,
         "StreamId": str,
-        "Status": Literal["ACTIVE", "COMPLETED", "CANCELED", "FAILED", "IMPAIRED"],
+        "Status": StreamStatus,
         "KinesisConfiguration": "KinesisConfigurationTypeDef",
         "StreamName": str,
     },
@@ -67,7 +71,7 @@ _OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
         "InclusiveStartTime": datetime,
         "ExclusiveEndTime": datetime,
         "Arn": str,
-        "ErrorCause": Literal["KINESIS_STREAM_NOT_FOUND", "IAM_PERMISSION_REVOKED"],
+        "ErrorCause": ErrorCause,
     },
     total=False,
 )
@@ -85,7 +89,7 @@ JournalS3ExportDescriptionTypeDef = TypedDict(
         "LedgerName": str,
         "ExportId": str,
         "ExportCreationTime": datetime,
-        "Status": Literal["IN_PROGRESS", "COMPLETED", "CANCELLED"],
+        "Status": ExportStatus,
         "InclusiveStartTime": datetime,
         "ExclusiveEndTime": datetime,
         "S3ExportConfiguration": "S3ExportConfigurationTypeDef",
@@ -109,17 +113,12 @@ class KinesisConfigurationTypeDef(
 
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
-    {
-        "Name": str,
-        "State": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
-        "CreationDateTime": datetime,
-    },
+    {"Name": str, "State": LedgerState, "CreationDateTime": datetime},
     total=False,
 )
 
 _RequiredS3EncryptionConfigurationTypeDef = TypedDict(
-    "_RequiredS3EncryptionConfigurationTypeDef",
-    {"ObjectEncryptionType": Literal["SSE_KMS", "SSE_S3", "NO_ENCRYPTION"]},
+    "_RequiredS3EncryptionConfigurationTypeDef", {"ObjectEncryptionType": S3ObjectEncryptionType}
 )
 _OptionalS3EncryptionConfigurationTypeDef = TypedDict(
     "_OptionalS3EncryptionConfigurationTypeDef", {"KmsKeyArn": str}, total=False
@@ -148,7 +147,7 @@ CreateLedgerResponseTypeDef = TypedDict(
     {
         "Name": str,
         "Arn": str,
-        "State": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
+        "State": LedgerState,
         "CreationDateTime": datetime,
         "DeletionProtection": bool,
     },
@@ -171,7 +170,7 @@ DescribeLedgerResponseTypeDef = TypedDict(
     {
         "Name": str,
         "Arn": str,
-        "State": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
+        "State": LedgerState,
         "CreationDateTime": datetime,
         "DeletionProtection": bool,
     },
@@ -248,7 +247,7 @@ UpdateLedgerResponseTypeDef = TypedDict(
     {
         "Name": str,
         "Arn": str,
-        "State": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
+        "State": LedgerState,
         "CreationDateTime": datetime,
         "DeletionProtection": bool,
     },
